==> haskell-either-5.0.1.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1.1
id: either-5.0.1.1-7qf8PhM5hrjHT52TvwWfA3
key: either-5.0.1.1-7qf8PhM5hrjHT52TvwWfA3
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: c5a7a541876e4d06fd1c0b9157cd89e7
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/either-5.0.1.1
hs-libraries: HSeither-5.0.1.1-7qf8PhM5hrjHT52TvwWfA3
depends:
    base-4.12.0.0 bifunctors-5.5.6-1hzbr6CRsZhGc3TV5tucLZ mtl-2.2.2
    profunctors-5.5.1-6DNrH25YhHECVaJNHzhHZx
    semigroupoids-5.3.3-AQtiKPqhF0dKZgZBy40uPE
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.1.1-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1.1
id: either-5.0.1.1-pTpgTGMlem7ATaPoKVM3S
key: either-5.0.1.1-pTpgTGMlem7ATaPoKVM3S
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: 5ce6aaa276684e63021f41a95b4622c2
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/either-5.0.1.1
hs-libraries: HSeither-5.0.1.1-pTpgTGMlem7ATaPoKVM3S
depends:
    base-4.12.0.0 bifunctors-5.5.6-MQKwXXAtJF9RK97Pcm9hN mtl-2.2.2
    profunctors-5.5.1-EIsjC0IwHL893JCIzxMeb8
    semigroupoids-5.3.4-FiWBu6qk7xgG3YPUsLmt4U
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
